==> m2m-qvtoml-SDK-1.0.0.zip: org/eclipse/m2m/internal/qvt/oml/common/ui/action/EObjectWindowActionDelegate.java <==
/*******************************************************************************
 * Copyright (c) 2007 Borland Software Corporation
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Borland Software Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.m2m.internal.qvt.oml.common.ui.action;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.m2m.internal.qvt.oml.emf.util.EmfUtil;



public abstract class EObjectWindowActionDelegate extends WindowActionDelegate {
    @Override
	public void selectionChanged(IAction action, ISelection selection) {
        super.selectionChanged(action, selection);
        EObject sel = getSelectedEObject(false);
        action.setEnabled(sel != null || getSelectedElement() instanceof IFile);
    }

    protected EObject getSelectedEObject() {
        return getSelectedEObject(true);
    }
    
    private EObject getSelectedEObject(boolean considerFiles) {
        Object sel = super.getSelectedElement();
        if(sel instanceof EObject) {
            return (EObject)sel;
        }
        
        if(sel instanceof IAdaptable) {
            IAdaptable adaptable = (IAdaptable)sel;
            EObject adapted = (EObject)adaptable.getAdapter(EObject.class);
            if(adapted != null) {
                return adapted;
            }
        }
        
        if(sel instanceof IFile && considerFiles) {
            IFile file = (IFile)sel;
            try {
                EObject model = EmfUtil.loadModel(URI.createPlatformResourceURI(file.getFullPath().toString(), false));
                if(model != null) {
                    return model;
                }
            }
            catch(Exception ignore) {
            }
        }

        return null;
    }
}

==> m2m-qvtoml-SDK-1.0.1.zip: org/eclipse/m2m/internal/qvt/oml/common/ui/action/EObjectWindowActionDelegate.java <==
/*******************************************************************************
 * Copyright (c) 2007 Borland Software Corporation
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Borland Software Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.m2m.internal.qvt.oml.common.ui.action;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.m2m.internal.qvt.oml.emf.util.EmfUtil;



public abstract class EObjectWindowActionDelegate extends WindowActionDelegate {
    @Override
	public void selectionChanged(IAction action, ISelection selection) {
        super.selectionChanged(action, selection);
        EObject sel = getSelectedEObject(false);
        action.setEnabled(sel != null || getSelectedElement() instanceof IFile);
    }

    protected EObject getSelectedEObject() {
        return getSelectedEObject(true);
    }
    
    private EObject getSelectedEObject(boolean considerFiles) {
        Object sel = super.getSelectedElement();
        if(sel instanceof EObject) {
            return (EObject)sel;
        }
        
        if(sel instanceof IAdaptable) {
            IAdaptable adaptable = (IAdaptable)sel;
            EObject adapted = (EObject)adaptable.getAdapter(EObject.class);
            if(adapted != null) {
                return adapted;
            }
        }
        
        if(sel instanceof IFile && considerFiles) {
            IFile file = (IFile)sel;
            try {
            	URI resourceURI = URI.createPlatformResourceURI(file.getFullPath().toString(), false);
                EObject model = EmfUtil.loadModel(resourceURI);
                if(model != null) {
                    return model;
                }
            }
            catch(Exception ignore) {
            }
        }

        return null;
    }
}
